.. collective.easyform documentation master file, created by
   sphinx-quickstart on Mon Feb 24 23:51:08 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to collective.easyform's documentation!
===============================================

.. image:: https://travis-ci.org/quintagroup/collective.easyform.png?branch=master
    :target: https://travis-ci.org/quintagroup/collective.easyform
    :alt: Travis CI status

.. image:: https://coveralls.io/repos/quintagroup/collective.easyform/badge.png?branch=master
    :target: https://coveralls.io/r/quintagroup/collective.easyform?branch=master
    :alt: Coveralls status

.. image:: https://badge.fury.io/py/collective.easyform.png
    :target: http://badge.fury.io/py/collective.easyform
    :alt: Fury Python

.. image:: https://badge.fury.io/gh/quintagroup%2Fcollective.easyform.png
    :target: http://badge.fury.io/gh/quintagroup%2Fcollective.easyform
    :alt: Fury Github

.. image:: https://pypip.in/d/collective.easyform/badge.png
    :target: https://pypi.python.org/pypi/collective.easyform/
    :alt: Downloads

.. image:: https://pypip.in/v/collective.easyform/badge.png
    :target: https://pypi.python.org/pypi/collective.easyform/
    :alt: Latest Version

.. image:: https://pypip.in/wheel/collective.easyform/badge.png
    :target: https://pypi.python.org/pypi/collective.easyform/
    :alt: Wheel Status

.. image:: https://pypip.in/egg/collective.easyform/badge.png
    :target: https://pypi.python.org/pypi/collective.easyform/
    :alt: Egg Status

.. image:: https://pypip.in/license/collective.easyform/badge.png
    :target: https://pypi.python.org/pypi/collective.easyform/
    :alt: License

collective.easyform enables lets you create custom Plone forms easily; it provides a through-the-web form builder
you use to add fields, widgets, actions and validators.
EasyForm is similar to Products.PloneFormGen, based on the old Archetypes content type framework, but
EasyForm is based on Dexterity, the platform for content types in Plone 5 and later.


Contents
--------

.. toctree::
   :maxdepth: 2

   adding
   fields
   actions
   tests


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

